import numpy as np
from skimage.io import imread
from skimage.transform import resize
from utils import rle_decode
from tqdm import tqdm

def get_train_data(imgs_path, train_df, IMG_HEIGHT = 256,IMG_WIDTH = 256,IMG_CHANNELS = 1):
	train_ids = train_df['id'].unique().tolist()
	X_train = np.zeros((train_df['id'].nunique(), IMG_HEIGHT, IMG_WIDTH, IMG_CHANNELS), dtype=np.uint8)
	Y_train = np.zeros((train_df['id'].nunique(), IMG_HEIGHT, IMG_WIDTH, 1), dtype=np.bool)
	
	print('Getting and resizing train images and masks ----- ')

	for n, id_ in tqdm(enumerate(train_ids), total=len(train_ids)):
		img = imread(imgs_path + id_ + '.png')[:,:]
		img = resize(img, (IMG_HEIGHT, IMG_WIDTH), mode='constant', preserve_range=True)
		img = np.expand_dims(img, axis = 2)
		X_train[n] = img
		
		labels = train_df[train_df["id"] == id_]["annotation"].tolist()
		mask = np.zeros((520, 704, 1))
		for label in labels:
			mask += rle_decode(label, shape=(520, 704, 1), color = 1)
		mask = mask.clip(0, 1)
		mask = mask[:,:,0]
		mask = np.expand_dims(resize(mask, (IMG_HEIGHT, IMG_WIDTH), mode='constant', preserve_range=True), axis=-1)
		
		Y_train[n] = mask

	print('Done!')
	
	return X_train, Y_train

	
def get_test_data(imgs_path, test_df, IMG_HEIGHT = 256,IMG_WIDTH = 256,IMG_CHANNELS = 1):
	test_ids = test_df['id'].unique().tolist()
	X_test = np.zeros((test_df['id'].nunique(), IMG_HEIGHT, IMG_WIDTH, IMG_CHANNELS), dtype=np.uint8)

	print('Getting and resizing test images ---- ')

	for n, id_ in tqdm(enumerate(test_ids), total=len(test_ids)):
		img = imread(imgs_path + id_ + '.png')[:,:]
		img = resize(img, (IMG_HEIGHT, IMG_WIDTH), mode='constant', preserve_range=True)
		img = np.expand_dims(img, axis = 2)
		X_test[n] = img

	print('Done!')
	
	return X_test